@@ -11,8 +11,7 @@
 from __future__ import annotations
 
 from datetime import datetime
-import importlib
-import inspect
+import importlib.util
 import json
 import os
 import tempfile
@@ -96,12 +95,24 @@ class EntryPoint:
 
         # Find the absolute path to the repository and then the relative path to the module.
         # This will be used in the creation of the code 'bundle' when building the image.
-        path_to_repo = run_shell_command("git rev-parse --show-toplevel")[0]
-        path_to_code = inspect.getfile(func)
-        package_root = path_to_code
-        module_parts = self.module_name.split(".")
-        for _ in module_parts:
-            package_root = os.path.dirname(package_root)
+        module_spec = importlib.util.find_spec(func.__module__)
+        if not module_spec:
+            raise RepoValidationError(f"Cannot find spec for {self.module_name}")
+        # Resolve the filesystem directory of the top package for module_name
+        if module_spec.submodule_search_locations:
+            # It's a package; get its directory
+            package_root = os.path.abspath(
+                next(iter(module_spec.submodule_search_locations))
+            )
+        elif module_spec.origin:
+            # It's a module; use its containing directory
+            package_root = os.path.abspath(os.path.dirname(module_spec.origin))
+        else:
+            raise RepoValidationError(f"Cannot resolve path for {self.module_name}")
+
+        path_to_repo = run_shell_command(
+            f"cd {package_root} && git rev-parse --show-toplevel"
+        )[0]
         path_to_module = os.path.relpath(package_root, path_to_repo)
         self.path_to_repo = path_to_repo
         self.path_to_module = path_to_module
@@ -123,7 +134,7 @@ class EntryPoint:
         return f"EntryPoint({self.function_name} from {self.module_name}, type={self.type})"
 
     def __str__(self):
-        return f"{self.module_name}.{self.function_name}"
+        return f"{self.module_name}:{self.function_name}"
 
 
 class Job:
@@ -277,20 +288,25 @@ class Job:
         2. Check if the local commit matches the remote HEAD (the repo is synced with the remote).
         Returns a tuple of (branch: str, commit_hash: str).
         """
-        local_commit = run_shell_command("git rev-parse HEAD")[0]
-        branch_name = run_shell_command("git rev-parse --abbrev-ref HEAD")[0]
+        path_to_repo = self.image.path_to_repo or "."
+        local_commit = run_shell_command(f"cd {path_to_repo} && git rev-parse HEAD")[0]
+        branch_name = run_shell_command(
+            f"cd {path_to_repo} && git rev-parse --abbrev-ref HEAD"
+        )[0]
 
         if os.getenv("DATATAILR_ALLOW_UNSAFE_SCHEDULING", "false").lower() == "true":
             return branch_name, local_commit
-        return_code = run_shell_command("git diff --exit-code")[1]
-        is_committed = return_code == 0
+        return_code = run_shell_command(f"cd {path_to_repo} && git diff --exit-code")
+        is_committed = return_code is not None and return_code[1] == 0
 
         if not is_committed:
             raise RepoValidationError(
                 "Please commit your changes before running the job."
             )
 
-        remote_commit = run_shell_command("git ls-remote origin HEAD")[0].split("\t")[0]
+        remote_commit = run_shell_command(
+            f"cd {path_to_repo} && git ls-remote origin HEAD"
+        )[0].split("\t")[0]
 
         if local_commit != remote_commit:
             raise RepoValidationError(
