@@ -18,7 +18,6 @@ from typing import Any, Dict, List, Optional, Sequence, Set, Tuple, Union
 import uuid
 
 from datatailr import Image
-from datatailr.dt_json import encode_json
 from datatailr.errors import BatchJobError
 from datatailr.logging import DatatailrLogger
 from datatailr.scheduler.base import (
@@ -114,7 +113,7 @@ class BatchJob:
             isinstance(dep, int) for dep in self.dependencies
         ), "All dependencies must be integers representing job IDs."
         self.dag.add_job(self)
-        self.__argument_mapping = argument_mapping or {}
+        self.argument_mapping = argument_mapping or {}
 
     def __call__(self, *args, **kwds) -> BatchJob:
         """
@@ -200,6 +199,7 @@ class BatchJob:
         """
         return {
             "display_name": self.name,
+            "name": self.name,
             "child_number": self.__id,
             "entrypoint": str(self.entrypoint),
             "memory": self.resources.memory if self.resources else DEFAULT_TASK_MEMORY,
@@ -235,7 +235,7 @@ class BatchJob:
 
     def __add_dependency__(self, other):
         self.dependencies.add(other.__id)
-        arg_name = self.__argument_mapping.get(other.name, other.name)
+        arg_name = self.argument_mapping.get(other.name, other.name)
         if arg_name is not None:
             self.__args[arg_name] = other
 
@@ -282,7 +282,6 @@ class BatchJob:
                 "DATATAILR_BATCH_ID": str(self.dag.id),
                 "DATATAILR_JOB_ID": str(self.__id),
                 "DATATAILR_JOB_NAME": self.name,
-                "DATATAILR_JOB_ARGUMENT_MAPPING": encode_json(self.__argument_mapping),
             }
             self.entrypoint(env=env)
         else:
@@ -464,9 +463,23 @@ class Batch(Job):
         def arg_name(arg: Union[BatchJob, str]) -> str:
             return arg.name if isinstance(arg, BatchJob) else arg
 
+        def merged(dst: dict[str, str], src: dict[str, str]) -> dict[str, str]:
+            # copy so we don't mutate the original mapping
+            out = dict(dst)
+            seen_vals = set(out.values())
+            for k, v in src.items():
+                if v not in seen_vals:
+                    out[k] = v
+                    seen_vals.add(v)
+            return out
+
         args = {
-            j.name: {k: arg_name(v) for k, v in j.args.items()} for j in self.__jobs
+            j.name: merged(
+                j.argument_mapping, {k: arg_name(v) for k, v in j.args.items()}
+            )
+            for j in self.__jobs
         }
+
         __ARGUMENTS_CACHE__.add_arguments(self.id, args)
         if not self.__local_run and is_dt_installed():
             return super().run()
