@@ -162,7 +162,7 @@ class User:
         last_name: str,
         email: str,
         password: str,
-        primary_group: int,
+        primary_group: str,
         is_system_user: bool = False,
     ) -> Optional["User"]:
         if is_system_user:
@@ -177,6 +177,7 @@ class User:
                 email=email,
                 primary_group=primary_group,
                 system=is_system_user,
+                json_enrichened=True,
             )
         else:
             new_user = __client__.add(
@@ -187,9 +188,10 @@ class User:
                 password=password,
                 primary_group=primary_group,
                 system=is_system_user,
+                json_enrichened=True,
             )
 
-        return new_user
+        return User(new_user["name"]) if new_user else None
 
     @staticmethod
     def exists(name: str) -> bool:
