@@ -27,20 +27,24 @@
 #     DATATAILR_GID - the group ID of the group as it is defined in the system.
 #     DATATAILR_JOB_TYPE - the type of job to run. (batch\service\app\excel\IDE)
 # Job environment variables (not all are always relevant, depending on the job type):
-#     DATATAILR_JOB_ARGUMENT_MAPPING - a JSON string mapping job argument names to their
 #     DATATAILR_BATCH_RUN_ID - the unique identifier for the batch run.
 #     DATATAILR_BATCH_ID - the unique identifier for the batch.
 #     DATATAILR_JOB_ID - the unique identifier for the job.
 
 
+import subprocess
 import os
+import sys
 from typing import Tuple
 from datatailr.logging import DatatailrLogger
-from datatailr.dt_json import encode_json
-
+from datatailr.utils import is_dt_installed
 
 logger = DatatailrLogger(os.path.abspath(__file__)).get_logger()
 
+if not is_dt_installed():
+    logger.error("Datatailr is not installed.")
+    sys.exit(1)
+
 
 def get_env_var(name: str, default: str | None = None) -> str:
     """
@@ -77,71 +81,95 @@ def create_user_and_group() -> Tuple[str, str]:
     return user, group
 
 
-def run_command_as_user(command: str, user: str, env_vars: dict):
+def run_command_as_user(command: str | list, user: str, env_vars: dict):
     """
     Run a command as a specific user with the given environment variables.
     """
-    env_vars.update({"PATH": get_env_var("PATH")})
-    env_vars.update({"PYTHONPATH": get_env_var("PYTHONPATH")})
-    env_vars_str = " ".join(f"{key}='{value}'" for key, value in env_vars.items())
-    full_command = f"sudo -u {user} {env_vars_str} {command}"
-    logger.debug(f"Running command: {full_command}")
-    os.system(full_command)
+    if isinstance(command, str):
+        command = command.split(" ")
+    env_vars = {
+        "PATH": get_env_var("PATH", ""),
+        "PYTHONPATH": get_env_var("PYTHONPATH", ""),
+    } | env_vars
+
+    env_kv = [f"{k}={v}" for k, v in env_vars.items()]
+    argv = ["sudo", "-u", user, "env", *env_kv, "bash", "-lc", *command]
+
+    try:
+        result = subprocess.run(
+            argv,
+            check=True,  # raises if returncode != 0
+            capture_output=True,
+            text=True,
+        )
+        logger.info(f"stdout: {result.stdout}")
+        logger.debug(f"stderr: {result.stderr}")
+    except subprocess.CalledProcessError as e:
+        logger.error(f"Command failed with exit code {e.returncode}")
+        logger.error(f"stderr: {e.stderr}")
+        sys.exit(1)
 
 
 def main():
-    logger.info(f"Env inside datatailr_run.py: {os.environ}")
     user, _ = create_user_and_group()
     job_type = get_env_var("DATATAILR_JOB_TYPE")
 
-    job_name = get_env_var("DATATAILR_JOB_NAME")
-    job_id = get_env_var("DATATAILR_JOB_ID")
+    env = {
+        "DATATAILR_JOB_TYPE": job_type,
+        "DATATAILR_JOB_NAME": get_env_var("DATATAILR_JOB_NAME"),
+        "DATATAILR_JOB_ID": get_env_var("DATATAILR_JOB_ID"),
+    }
 
     if job_type == "batch":
         run_id = get_env_var("DATATAILR_BATCH_RUN_ID")
         batch_id = get_env_var("DATATAILR_BATCH_ID")
-        job_argument_mapping = get_env_var(
-            "DATATAILR_JOB_ARGUMENT_MAPPING", encode_json({})
-        )
         entrypoint = get_env_var("DATATAILR_BATCH_ENTRYPOINT")
         env = {
             "DATATAILR_BATCH_RUN_ID": run_id,
             "DATATAILR_BATCH_ID": batch_id,
-            "DATATAILR_JOB_ID": job_id,
             "DATATAILR_BATCH_ENTRYPOINT": entrypoint,
-            "DATATAILR_JOB_ARGUMENT_MAPPING": job_argument_mapping,
-        }
+        } | env
         run_command_as_user("datatailr_run_batch", user, env)
     elif job_type == "service":
         port = get_env_var("DATATAILR_SERVICE_PORT")
         entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
         env = {
-            "DATATAILR_JOB_NAME": job_name,
-            "DATATAILR_JOB_ID": job_id,
             "DATATAILR_ENTRYPOINT": entrypoint,
             "DATATAILR_SERVICE_PORT": port,
-        }
+        } | env
         run_command_as_user("datatailr_run_service", user, env)
     elif job_type == "app":
         entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
         env = {
-            "DATATAILR_JOB_NAME": job_name,
-            "DATATAILR_JOB_ID": job_id,
             "DATATAILR_ENTRYPOINT": entrypoint,
-        }
+        } | env
         run_command_as_user("datatailr_run_app", user, env)
     elif job_type == "excel":
         host = get_env_var("DATATAILR_HOST")
         entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
         env = {
-            "DATATAILR_JOB_NAME": job_name,
-            "DATATAILR_JOB_ID": job_id,
             "DATATAILR_ENTRYPOINT": entrypoint,
             "DATATAILR_HOST": host,
-        }
+        } | env
         run_command_as_user("datatailr_run_excel", user, env)
     elif job_type == "IDE":
-        pass
+        command = [
+            "code-server",
+            "--auth=none",
+            "--bind-addr=0.0.0.0:8080",
+            f'--app-name="Datatailr IDE {get_env_var("DATATAILR_USER")}"',
+        ]
+        run_command_as_user(command, user, env)
+    elif job_type == "jupyter":
+        command = [
+            "jupyter-lab",
+            "--ip='*'",
+            "--port=8080",
+            "--no-browser",
+            "--NotebookApp.token=''",
+            "--NotebookApp.password=''",
+        ]
+        run_command_as_user(command, user, env)
     else:
         raise ValueError(f"Unknown job type: {job_type}")
 
